@@ -52,9 +52,9 @@ def sourcelinks_process_docstring(
 	:param app: The Sphinx app
 	:param what:
 	:param name: The name of the object being documented
-	:param obj:
-	:param options:
-	:param lines:
+	:param obj: The object being documented.
+	:param options: Mapping of autodoc options to values.
+	:param lines: List of strings representing the current contents of the docstring.
 	"""
 
 	if (
@@ -80,7 +80,7 @@ def setup(app: Sphinx) -> Dict[str, Any]:
 	app.setup_extension("sphinx_toolbox.source")
 	app.setup_extension("sphinx.ext.autodoc")
 
-	app.connect('autodoc-process-docstring', sourcelinks_process_docstring)
+	app.connect("autodoc-process-docstring", sourcelinks_process_docstring)
 	app.add_config_value("autodoc_show_sourcelink", False, "env", [bool])
 
 	return {
