@@ -91,13 +91,15 @@ import autodocsumm  # type: ignore
 from domdf_python_tools.stringlist import StringList
 from sphinx.application import Sphinx
 from sphinx.config import ENUM
+from sphinx.ext.autodoc import ClassDocumenter
 from sphinx.ext.autosummary import Autosummary
 
 # this package
 from sphinx_toolbox import __version__
+from sphinx_toolbox.more_autodoc.utils import allow_subclass_add
 from sphinx_toolbox.utils import get_first_matching
 
-__all__ = ["setup", "PatchedAutosummary"]
+__all__ = ["setup", "PatchedAutosummary", "PatchedAutoSummClassDocumenter"]
 
 
 def add_autosummary(self):
@@ -166,7 +168,7 @@ class PatchedAutosummary(Autosummary):
 		:param name:
 		:param prefixes:
 
-		:return: The real name of the object, the object, the parent of the object, and the name of the moudle.
+		:return: The real name of the object, the object, the parent of the object, and the name of the module.
 		"""
 
 		real_name, obj, parent, modname = super().import_by_name(name=name, prefixes=prefixes)
@@ -174,6 +176,21 @@ class PatchedAutosummary(Autosummary):
 		return real_name, obj, parent, modname
 
 
+class PatchedAutoSummClassDocumenter(autodocsumm.AutoSummClassDocumenter):
+	"""
+	Patched version of :class:`autodocsumm.AutoSummClassDocumenter`
+	which doesn't show summary tables for aliased objects.
+
+	.. versionadded:: 0.9.0
+	"""
+
+	def add_content(self, *args, **kwargs):
+		ClassDocumenter.add_content(self, *args, **kwargs)
+
+		if not self.doc_as_attr:
+			self.add_autosummary()
+
+
 def setup(app: Sphinx) -> Dict[str, Any]:
 	"""
 	Setup :mod:`sphinx_toolbox.more_autosummary`.
@@ -188,6 +205,8 @@ def setup(app: Sphinx) -> Dict[str, Any]:
 
 	autodocsumm.AutosummaryDocumenter.add_autosummary = add_autosummary
 
+	allow_subclass_add(app, PatchedAutoSummClassDocumenter)
+
 	app.add_config_value(
 			"autodocsumm_member_order",
 			"alphabetical",
